summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--modules/TDEL10n.cmake5
1 files changed, 3 insertions, 2 deletions
diff --git a/modules/TDEL10n.cmake b/modules/TDEL10n.cmake
index f45cc53..6a51dad 100644
--- a/modules/TDEL10n.cmake
+++ b/modules/TDEL10n.cmake
@@ -514,9 +514,10 @@ macro( tde_l10n_create_template )
endif( )
endforeach( )
# pick desktop files - *.desktop, *.directory, *.kcsrc, *.protocol and *.themerc
foreach( _src ${_files} )
- if( ${_src} MATCHES "\\.(desktop|directory|kcsrc|protocol|themerc)(\\.cmake)?$" )
+ if( ${_src} MATCHES "\\.(desktop|directory|kcsrc|protocol|theme|themerc)(\\.cmake)?$"
+ OR ${_src} MATCHES "(^|/)eventsrc(\\.cmake)?$" )
list( APPEND _desktops ${_src} )
list( REMOVE_ITEM _files ${_src} )
endif( )
@@ -514,9 +514,10 @@ macro( tde_l10n_create_template )
endif( )
endforeach( )
- # pick desktop files - *.desktop, *.directory, *.kcsrc, *.protocol and *.themerc
+ # pick desktop files - *.desktop, *.directory, *.kcsrc, *.protocol, *.theme, *.themerc and eventsrc
foreach( _src ${_files} )